@@ -1,6 +1,7 @@
 __all__ = ('language', 'stemmer')
 
 from .arabic_stemmer import ArabicStemmer
+from .armenian_stemmer import ArmenianStemmer
 from .basque_stemmer import BasqueStemmer
 from .catalan_stemmer import CatalanStemmer
 from .danish_stemmer import DanishStemmer
@@ -22,13 +23,16 @@ from .porter_stemmer import PorterStemmer
 from .portuguese_stemmer import PortugueseStemmer
 from .romanian_stemmer import RomanianStemmer
 from .russian_stemmer import RussianStemmer
+from .serbian_stemmer import SerbianStemmer
 from .spanish_stemmer import SpanishStemmer
 from .swedish_stemmer import SwedishStemmer
 from .tamil_stemmer import TamilStemmer
 from .turkish_stemmer import TurkishStemmer
+from .yiddish_stemmer import YiddishStemmer
 
 _languages = {
     'arabic': ArabicStemmer,
+    'armenian': ArmenianStemmer,
     'basque': BasqueStemmer,
     'catalan': CatalanStemmer,
     'danish': DanishStemmer,
@@ -50,10 +54,12 @@ _languages = {
     'portuguese': PortugueseStemmer,
     'romanian': RomanianStemmer,
     'russian': RussianStemmer,
+    'serbian': SerbianStemmer,
     'spanish': SpanishStemmer,
     'swedish': SwedishStemmer,
     'tamil': TamilStemmer,
     'turkish': TurkishStemmer,
+    'yiddish': YiddishStemmer,
 }
 
 try:
@@ -66,7 +72,7 @@ def algorithms():
     if cext_available:
         return Stemmer.language()
     else:
-        return list(_languages.key())
+        return list(_languages.keys())
 
 def stemmer(lang):
     if cext_available:
